topleveltools
=============

.. automodule:: abjad.tools.topleveltools

.. only:: html

   Functions
   ---------

   .. autosummary::

      ~abjad.tools.topleveltools.attach.attach
      ~abjad.tools.topleveltools.detach.detach
      ~abjad.tools.topleveltools.graph.graph
      ~abjad.tools.topleveltools.inspect_.inspect_
      ~abjad.tools.topleveltools.iterate.iterate
      ~abjad.tools.topleveltools.mutate.mutate
      ~abjad.tools.topleveltools.new.new
      ~abjad.tools.topleveltools.override.override
      ~abjad.tools.topleveltools.parse.parse
      ~abjad.tools.topleveltools.persist.persist
      ~abjad.tools.topleveltools.play.play
      ~abjad.tools.topleveltools.select.select
      ~abjad.tools.topleveltools.set_.set_
      ~abjad.tools.topleveltools.show.show
